MLZ
---

Amagnet (Garfield)
..................

.. automodule:: frappy_mlz.amagnet
    :show-inheritance:
    :members:


Entangle Framework
..................

.. automodule:: frappy_mlz.entangle
    :show-inheritance:
    :members:


